@@ -10,10 +10,11 @@
 print.processing_time <- function(x, ...) {
 	data <- x
 
-	if(attr(data, "level") == "log") {
+	if(attr(data, "level") == "log" & is.null(attr(data, "groups"))) {
 		attr(data, "raw") <- NULL
 		attr(data, "level") <- NULL
 		attr(data, "mapping") <- NULL
+		class(data) <- "numeric"
 		print.default(data)
 	}
 	else {
