@@ -1,11 +1,12 @@
 
 processing_time_activity <- function(eventlog,
-									 units) {
+									 units,
+									 work_schedule) {
 
 	relative_frequency <- NULL
 
 	eventlog %>%
-		processing_time_activity_instance(units = units) -> raw
+		processing_time_activity_instance(units = units, work_schedule = work_schedule) -> raw
 
 	raw %>%
 		group_by(!!activity_id_(eventlog)) %>%
