@@ -7,7 +7,6 @@ resource_frequency_resource <- function(eventlog) {
 		group_by(!!resource_id_(eventlog), !!activity_instance_id_(eventlog)) %>%
 		summarize() %>%
 		summarize(absolute = n()) %>%
-		mutate(relative = absolute/sum(absolute)) %>%
-		arrange(-absolute)
+		mutate(relative = absolute/sum(absolute))
 
 }
