@@ -2,11 +2,11 @@
 
 
 trace_length_log <- function(eventlog) {
-
+	absolute <- NULL
 	trace_length_case(eventlog) -> raw
 
 	raw %>%
-		pull(trace_length) %>%
+		pull(absolute) %>%
 		summary_statistics -> output
 
 	attr(output, "raw") <- raw
